import unittest
import ast
import inspect

def get_decorators(cls):
    target = cls
    decorators = {}

    def visit_FunctionDef(node):
        decorators[node.name] = []
        for n in node.decorator_list:
            name = ''
            if isinstance(n, ast.Call):
                name = n.func.attr if isinstance(n.func, ast.Attribute) else n.func.id
            else:
                name = n.attr if isinstance(n, ast.Attribute) else n.id

            decorators[node.name].append(name)

    node_iter = ast.NodeVisitor()
    node_iter.visit_FunctionDef = visit_FunctionDef
    node_iter.visit(ast.parse(inspect.getsource(target)))
    return decorators

def focus(test_func):
    def wrapper(*args, **kwargs):
        # Set a flag indicating the focused test
        test_func.__unittest_focus__ = True
        return test_func(*args, **kwargs)
    return wrapper

# Extend the unittest.TestCase to skip non-focused tests
class FocusedTestCase(unittest.TestCase):
    def setUp(self):
        # Get decorators for the current class
        decorators = get_decorators(type(self))
        
        # Check if there are focused tests
        focused_tests = [name for name, decs in decorators.items() if 'focus' in decs]
        if focused_tests and self._testMethodName not in focused_tests:
            self.skipTest('Skipped due to focus')


from setuptools import setup, find_packages

setup(
    name='focused_unittest',
    version='0.1.0',
    description='Decorator to select only one unit test to be run.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Stan',
    author_email='barsv85@gmail.com',
    url='https://github.com/barsv/focused_unittest',
    py_modules=['focused_unittest'],
    packages=find_packages(),
    install_requires=[
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
